CubicBez
========

::

   from kurbopy import CubicBez, Point

   bez = CubicBez(
      Point(50.0, 100.0),
      Point(75.0, 100.0),
      Point(100.0, 100.0),
      Point(100.0, 75.0)
   )

.. autoclass:: kurbopy.CubicBez
   :members:
   :undoc-members:
